@@ -14,7 +14,14 @@ STAT_ENDPOINT = "https://api.statcord.com/v3/stats"
 class StatcordClient:
     """The base Statcord client class."""
 
-    def __init__(self, bot: commands.Bot, statcord_key: str, custom_1: Callable = None, custom_2: Callable = None) -> None:
+    def __init__(
+        self,
+        bot: commands.Bot,
+        statcord_key: str,
+        custom_1: Callable = None,
+        custom_2: Callable = None,
+        resource_stats: bool = True,
+    ) -> None:
         self.bot = bot
 
         self.statcord_key = statcord_key
@@ -41,12 +48,19 @@ class StatcordClient:
         self.logger = logging.getLogger("statcord")
         self.logger.setLevel(logging.WARNING)
 
+        # configuration
+        self.resource_stats = resource_stats
+
         # create aiohttp clientsession instance
         self._aiohttp_ses = aiohttp.ClientSession(loop=bot.loop)
 
         # create counters
-        net_io_counter = psutil.net_io_counters()
-        self._prev_net_usage = net_io_counter.bytes_sent + net_io_counter.bytes_recv
+        if self.resource_stats:
+            net_io_counter = psutil.net_io_counters()
+            self._prev_net_usage = net_io_counter.bytes_sent + net_io_counter.bytes_recv
+        else:
+            self._prev_net_usage = None
+
         self._popular_commands = defaultdict(int)
         self._command_count = 0
         self._active_users = set()
@@ -72,18 +86,7 @@ class StatcordClient:
     def _get_user_count(self) -> int:
         """Gets the user count of the bot as accurately as it can."""
 
-        if self.bot.intents.members or self.bot.intents.presences:
-            return len(self.bot.users)
-        else:
-            count = 0
-
-            for guild in self.bot.guilds:
-                try:
-                    count += guild.member_count
-                except (AttributeError, ValueError):
-                    pass
-
-            return count
+        return sum([g.member_count for g in self.bot.guilds if hasattr(g, "member_count") and g.member_count is not None])
 
     async def _command_ran(self, ctx: commands.Context) -> None:
         """Updates command-related statistics."""
@@ -122,18 +125,24 @@ class StatcordClient:
 
         self.logger.debug("Posting stats to Statcord...")
 
-        # get process details
-        mem = psutil.virtual_memory()
-        net_io_counter = psutil.net_io_counters()
-        cpu_load = str(psutil.cpu_percent())
+        if self.resource_stats:
+            mem = psutil.virtual_memory()
+            mem_used = str(mem.used)
+            mem_load = str(mem.percent)
 
-        # get data ready to send + update old data
-        mem_used = str(mem.used)
-        mem_load = str(mem.percent)
+            cpu_load = str(psutil.cpu_percent())
 
-        total_net_usage = net_io_counter.bytes_sent + net_io_counter.bytes_recv  # current net usage
-        period_net_usage = str(total_net_usage - self._prev_net_usage)  # net usage to be sent
-        self._prev_net_usage = total_net_usage  # update previous net usage counter
+            net_io_counter = psutil.net_io_counters()
+            total_net_usage = net_io_counter.bytes_sent + net_io_counter.bytes_recv  # current net usage
+            period_net_usage = str(total_net_usage - self._prev_net_usage)  # net usage to be sent
+            self._prev_net_usage = total_net_usage  # update previous net usage counter
+        else:
+            mem_used = "0"
+            mem_load = "0"
+
+            cpu_load = "0"
+
+            period_net_usage = "0"
 
         data = {
             "id": str(self.bot.user.id),
@@ -172,6 +181,6 @@ class StatcordClient:
         elif resp.status == 429:
             self.logger.warning("Statcord is ratelimiting us.")
         elif resp.status != 200:
-            raise Exception(f"Statcord server response status was not 200 OK:\n{await resp.text()}")
+            raise Exception(f"Statcord server response status was not 200 OK (Was {resp.status}):\n{await resp.text()}")
         else:
             self.logger.debug("Successfully posted stats to Statcord.")
